(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[    226924,       4241]
NotebookOptionsPosition[    221410,       4157]
NotebookOutlinePosition[    221908,       4175]
CellTagsIndexPosition[    221865,       4172]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[StyleBox["Last checked 21 April, 2023",
 CellFrame->True,
 Background->GrayLevel[0.849989]]], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.851321730299733*^9, 3.851321747924562*^9}, 
   3.8513218075505953`*^9, {3.890897811719871*^9, 3.890897826726935*^9}, {
   3.890973965108789*^9, 3.8909739653874283`*^9}, {3.891080224224403*^9, 
   3.891080224709962*^9}},
 TextAlignment->Left,
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e00740cc-6281-478c-8bb6-75443996002a"],

Cell["Chapter 9, Section 9.3.3, Figure 9.7", "Section",
 CellChangeTimes->{{3.878562412934669*^9, 3.878562413354199*^9}, {
  3.8846087172978783`*^9, 3.884608735388258*^9}, {3.884692304467482*^9, 
  3.8846923048123302`*^9}, {3.884936708324288*^9, 3.8849367128241863`*^9}, {
  3.885014699065946*^9, 3.885014699641323*^9}, {3.8850436872873373`*^9, 
  3.8850437099391212`*^9}},ExpressionUUID->"98580719-04ac-49a4-b957-\
796e13d2fd0c"],

Cell[TextData[{
 "First we define a function ",
 StyleBox["CRTBP", "Input"],
 " which solves the circular restricted three-body problem for a given mass \
ratio and initial values of the position and velocity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884608962593175*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2196beda-83cc-4949-84e5-6855091b3920"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBP", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", "y0_", ",", "xd0_", ",", "yd0_"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"ctmin_", ",", " ", "ctmax_"}], "}"}]}], "]"}], ":=", "\n", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"eqns", " ", "=", 
      RowBox[{"{", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"r1", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{"r2", "[", "t_", "]"}], " ", ":=", " ", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"Apply", "[", 
            RowBox[{"Plus", ",", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{
                 RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}]}], "}"}], "^", "2"}]}], "]"}], 
           "]"}]}], ";", 
         RowBox[{
          RowBox[{
           RowBox[{"xd", "'"}], "[", "t", "]"}], " ", "==", " ", 
          RowBox[{
           RowBox[{"2", "*", 
            RowBox[{
             RowBox[{"y", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
           RowBox[{"x", "[", "t", "]"}], " ", "-", " ", 
           RowBox[{"mu1", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "+", "mu2"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}]}], " ", "-", " ", 
           RowBox[{"mu2", "*", 
            RowBox[{
             RowBox[{"(", 
              RowBox[{
               RowBox[{"x", "[", "t", "]"}], "-", "mu1"}], ")"}], "/", 
             RowBox[{
              RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}]}]}]}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{
          RowBox[{"yd", "'"}], "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", "2"}], "*", 
           RowBox[{
            RowBox[{"x", "'"}], "[", "t", "]"}]}], " ", "+", " ", 
          RowBox[{"y", "[", "t", "]"}], " ", "-", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"mu1", "/", 
              RowBox[{
               RowBox[{"r1", "[", "t", "]"}], "^", "3"}]}], " ", "+", " ", 
             RowBox[{"mu2", "/", 
              RowBox[{
               RowBox[{"r2", "[", "t", "]"}], "^", "3"}]}]}], ")"}], "*", 
           RowBox[{"y", "[", "t", "]"}]}]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"x", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "t", "]"}], " ", "==", " ", 
         RowBox[{
          RowBox[{"y", "'"}], "[", "t", "]"}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"x", "[", "ctmin", "]"}], "  ", "==", " ", "x0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"y", "[", "ctmin", "]"}], "  ", "==", " ", "y0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"xd", "[", "ctmin", "]"}], " ", "==", " ", "xd0"}], ",", 
        "\[IndentingNewLine]", 
        RowBox[{
         RowBox[{"yd", "[", "ctmin", "]"}], " ", "==", " ", "yd0"}]}], 
       "}"}]}], ";", 
     RowBox[{"NDSolve", "[", 
      RowBox[{"eqns", ",", " ", 
       RowBox[{"{", 
        RowBox[{"x", ",", "y", ",", "xd", ",", "yd"}], "}"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{"t", ",", "ctmin", ",", "ctmax"}], "}"}]}], "]"}]}]}], 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.884598673329917*^9, 3.884598776657687*^9}, 
   3.88503804742982*^9, {3.885038592349805*^9, 3.885038603185713*^9}},
 CellLabel->"In[1]:=",ExpressionUUID->"a0cc8023-92c0-48cc-8003-9af569b81a86"],

Cell[TextData[{
 "Next we define the Jacobi integral ",
 StyleBox["Jacobi", "Input"],
 " for use as a check on the accuracy of our solution."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"e62b02b3-a858-4e86-bbbf-40af19ca2286"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Jacobi", "[", 
   RowBox[{"mu_", ",", 
    RowBox[{"{", 
     RowBox[{"x_", ",", "y_", ",", "xd_", ",", "yd_"}], "}"}]}], "]"}], ":=", 
  " ", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", "=", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", 
      RowBox[{"mu2", "=", "mu"}], ",", " ", "r1", ",", " ", "r2"}], "}"}], 
    ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"r1", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "+", "mu2"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"Apply", "[", 
        RowBox[{"Plus", ",", 
         RowBox[{
          RowBox[{"{", 
           RowBox[{
            RowBox[{"x", "-", "mu1"}], ",", " ", "y"}], "}"}], "^", "2"}]}], 
        "]"}], "]"}]}], ";", 
     RowBox[{
      RowBox[{"x", "^", "2"}], "+", 
      RowBox[{"y", "^", "2"}], "+", 
      RowBox[{"2", "*", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"mu1", "/", "r1"}], "+", 
         RowBox[{"mu2", "/", "r2"}]}], ")"}]}], "-", 
      RowBox[{"xd", "^", "2"}], "-", 
      RowBox[{"yd", "^", "2"}]}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.88459882221215*^9, 3.8845988400166473`*^9}},
 CellLabel->"In[2]:=",ExpressionUUID->"cc76bdeb-e5fc-4e00-a682-cd7f21c16a0c"],

Cell[TextData[{
 "The function ",
 StyleBox["xy2ae", "Input"],
 " converts position and velocity to orbital elements.  Note that it assumes \
that the position and velocity are given in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.884609189347991*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b21a35eb-c629-442c-bfb9-7016cce5ed6b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"xy2ae", "[", 
   RowBox[{"mu_", ",", " ", "tposvel_List"}], "]"}], " ", ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "x", ",", " ", 
      "y", ",", " ", "xd", ",", " ", "yd", ",", " ", "ct", ",", "st", ",", 
      "rx", ",", "ry", ",", "r2", ",", "r", ",", "vx", ",", "vy", ",", "v2", 
      ",", "v", ",", "a", ",", "h", ",", "h2", ",", "rdot", ",", "e", ",", 
      "xor", ",", "yor", ",", "cpf", ",", "sf", ",", "cf", ",", "f", ",", 
      "cp", ",", "ce", ",", "se", ",", "cpdeg", ",", "ea", ",", "ma", ",", 
      "lam"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "x", ",", " ", "y", ",", " ", "xd", ",", " ", "yd"}], 
       "}"}], " ", "=", " ", "tposvel"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{
       RowBox[{"ct", "*", "x"}], "-", 
       RowBox[{"st", "*", "y"}]}]}], ";", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{
       RowBox[{"st", "*", "x"}], "+", 
       RowBox[{"ct", "*", "y"}]}]}], ";", 
     RowBox[{"r2", " ", "=", " ", 
      RowBox[{
       RowBox[{"x", "*", "x"}], "+", 
       RowBox[{"y", "*", "y"}]}]}], ";", 
     RowBox[{"r", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "r2", "]"}]}], ";", 
     RowBox[{"vx", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "ct"}], "-", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"vy", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xd", "-", "y"}], ")"}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"yd", "+", "x"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"v2", " ", "=", " ", 
      RowBox[{
       RowBox[{"vx", "*", "vx"}], " ", "+", " ", 
       RowBox[{"vy", "*", "vy"}]}]}], ";", 
     RowBox[{"v", " ", "=", " ", 
      RowBox[{"Sqrt", "[", "v2", "]"}]}], ";", 
     RowBox[{"a", " ", "=", " ", 
      RowBox[{"1", "/", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"2", "/", "r"}], " ", "-", " ", 
         RowBox[{"v2", "/", "mu1"}]}], ")"}]}]}], ";", 
     RowBox[{"h", " ", "=", " ", 
      RowBox[{
       RowBox[{"rx", "*", "vy"}], " ", "-", " ", 
       RowBox[{"ry", "*", "vx"}]}]}], ";", 
     RowBox[{"h2", " ", "=", " ", 
      RowBox[{"h", "*", "h"}]}], ";", 
     RowBox[{"rdot", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"rx", "*", "vx"}], "+", 
         RowBox[{"ry", "*", "vy"}]}], ")"}], "/", "r"}]}], ";", 
     RowBox[{"e", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{
         RowBox[{"h2", "/", "mu1"}], "/", "a"}]}], "]"}]}], ";", 
     RowBox[{"cpf", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"rx", ",", " ", "ry"}], "]"}]}], ";", 
     RowBox[{"cf", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{
         RowBox[{"a", "*", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{"1", "-", 
             RowBox[{"e", "*", "e"}]}], ")"}], "/", "r"}]}], "-", "1"}], 
        ")"}], "/", "e"}]}], ";", 
     RowBox[{"sf", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "e"}]}], ")"}], "*", 
       RowBox[{
        RowBox[{"rdot", "/", "h"}], "/", "e"}]}]}], ";", 
     RowBox[{"f", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"cf", ",", " ", "sf"}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"cpf", " ", "-", " ", "f"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cp", "/", "Degree"}], "]"}]}], ";", 
     RowBox[{"cpdeg", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{"cpdeg", ",", " ", "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"cpdeg", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"cpdeg", " ", "=", " ", 
        RowBox[{"cpdeg", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"ce", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"r", "/", "a"}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"se", " ", "=", " ", 
      RowBox[{
       RowBox[{"(", 
        RowBox[{"r", "*", 
         RowBox[{"rdot", "/", 
          RowBox[{"Sqrt", "[", 
           RowBox[{"mu1", "*", "a"}], "]"}]}]}], ")"}], "/", "e"}]}], ";", 
     RowBox[{"ea", " ", "=", " ", 
      RowBox[{"ArcTan", "[", 
       RowBox[{"ce", ",", "se"}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"ea", " ", "-", " ", 
       RowBox[{"e", "*", 
        RowBox[{"Sin", "[", "ea", "]"}]}]}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"Mod", "[", 
       RowBox[{
        RowBox[{"N", "[", 
         RowBox[{
          RowBox[{"(", 
           RowBox[{"ma", "+", "cp"}], ")"}], "/", "Degree"}], "]"}], ",", " ",
         "360"}], "]"}]}], ";", 
     RowBox[{"If", "[", 
      RowBox[{
       RowBox[{"lam", " ", "<", " ", "0"}], ",", " ", 
       RowBox[{"lam", " ", "=", " ", 
        RowBox[{"lam", " ", "+", " ", "360"}]}]}], "]"}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "a", ",", "e", ",", "cpdeg", ",", "lam"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.884599493746714*^9, 3.884599724772217*^9}},
 CellLabel->"In[3]:=",ExpressionUUID->"7a749214-1746-4618-a6ff-697ddfaa8116"],

Cell[TextData[{
 "The function ",
 StyleBox["ae2xy", "Input"],
 " converts orbital elements to position and velocity.  Note that it assumes \
that the position and velocity are returned in the rotating frame."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.884609242087802*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"454a8d3b-0bf3-479e-8a9f-22b4ef58bce3"],

Cell[BoxData[
 RowBox[{
  RowBox[{"ae2xy", "[", 
   RowBox[{"mu_", ",", " ", "elements_List"}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"mu1", " ", "=", " ", 
       RowBox[{"1", "-", "mu"}]}], ",", " ", "t", ",", " ", "a", ",", " ", 
      "e", ",", " ", "cpd", ",", " ", "lamd", ",", "cp", ",", "lam", ",", "n",
       ",", "ma", ",", "ea", ",", "rx", ",", "ry", ",", "r", ",", "ccp", ",", 
      "scp", ",", "eca", ",", "cea", ",", "sea", ",", "xdz", ",", "ydz", ",", 
      "xdi", ",", "ydi", ",", "ct", ",", "st", ",", "fe", ",", "x", ",", "y", 
      ",", "xd", ",", "yd", ",", "xi", ",", "yi"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "t", ",", " ", "a", ",", " ", "e", ",", " ", "cpd", ",", " ", "lamd"}],
        "}"}], " ", "=", " ", "elements"}], ";", 
     RowBox[{"ct", " ", "=", " ", 
      RowBox[{"Cos", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"st", " ", "=", " ", 
      RowBox[{"Sin", "[", 
       RowBox[{"t", "*", "2", "*", "Pi"}], "]"}]}], ";", 
     RowBox[{"fe", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"1", "-", 
        RowBox[{"e", "^", "2"}]}], "]"}]}], ";", 
     RowBox[{"cp", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"cpd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"ccp", " ", "=", " ", 
      RowBox[{"Cos", "[", "cp", "]"}]}], ";", 
     RowBox[{"scp", " ", "=", " ", 
      RowBox[{"Sin", "[", "cp", "]"}]}], ";", 
     RowBox[{"lam", " ", "=", " ", 
      RowBox[{"N", "[", 
       RowBox[{"lamd", "*", "Degree"}], "]"}]}], ";", 
     RowBox[{"n", " ", "=", " ", 
      RowBox[{"Sqrt", "[", 
       RowBox[{"mu1", "/", 
        RowBox[{"a", "^", "3"}]}], "]"}]}], ";", 
     RowBox[{"ma", " ", "=", " ", 
      RowBox[{"lam", "-", "cp"}]}], ";", 
     RowBox[{"eca", " ", "=", " ", 
      RowBox[{"ea", " ", "/.", " ", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{
          RowBox[{"ea", " ", "-", " ", 
           RowBox[{"e", " ", 
            RowBox[{"Sin", "[", "ea", "]"}]}]}], " ", "==", " ", "ma"}], ",", 
         " ", 
         RowBox[{"{", 
          RowBox[{"ea", ",", "ma"}], "}"}]}], "]"}]}]}], ";", 
     RowBox[{"cea", " ", "=", " ", 
      RowBox[{"Cos", "[", "eca", "]"}]}], ";", 
     RowBox[{"sea", " ", "=", " ", 
      RowBox[{"Sin", "[", "eca", "]"}]}], ";", 
     RowBox[{"rx", " ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"cea", "-", "e"}], ")"}]}]}], ";", 
     RowBox[{"ry", " ", "=", " ", 
      RowBox[{"a", "*", "fe", "*", "sea"}]}], ";", 
     RowBox[{"r", "  ", "=", " ", 
      RowBox[{"a", "*", 
       RowBox[{"(", 
        RowBox[{"1", "-", 
         RowBox[{"e", "*", "cea"}]}], ")"}]}]}], ";", 
     RowBox[{"xdz", " ", "=", 
      RowBox[{
       RowBox[{"-", "n"}], "*", "a", "*", "a", "*", 
       RowBox[{"sea", "/", "r"}]}]}], ";", 
     RowBox[{"ydz", " ", "=", " ", 
      RowBox[{"n", "*", "a", "*", "a", "*", "fe", "*", 
       RowBox[{"cea", "/", "r"}]}]}], ";", 
     RowBox[{"xdi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "ccp"}], "-", 
       RowBox[{"ydz", "*", "scp"}]}]}], ";", 
     RowBox[{"ydi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xdz", "*", "scp"}], "+", 
       RowBox[{"ydz", "*", "ccp"}]}]}], ";", 
     RowBox[{"xi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "ccp"}], "-", 
       RowBox[{"ry", "*", "scp"}]}]}], ";", 
     RowBox[{"yi", " ", "=", "  ", 
      RowBox[{
       RowBox[{"rx", "*", "scp"}], "+", 
       RowBox[{"ry", "*", "ccp"}]}]}], ";", 
     RowBox[{"x", " ", "=", "  ", 
      RowBox[{
       RowBox[{"xi", "*", "ct"}], "+", 
       RowBox[{"yi", "*", "st"}]}]}], ";", 
     RowBox[{"y", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", "xi"}], "*", "st"}], "+", 
       RowBox[{"yi", "*", "ct"}]}]}], ";", 
     RowBox[{"xd", " ", "=", "  ", 
      RowBox[{
       RowBox[{
        RowBox[{"(", 
         RowBox[{"xdi", "+", "yi"}], ")"}], "*", "ct"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "st"}]}]}], ";", 
     RowBox[{"yd", " ", "=", " ", 
      RowBox[{
       RowBox[{
        RowBox[{"-", 
         RowBox[{"(", 
          RowBox[{"xdi", "+", "yi"}], ")"}]}], "*", "st"}], "+", 
       RowBox[{
        RowBox[{"(", 
         RowBox[{"ydi", "-", "xi"}], ")"}], "*", "ct"}]}]}], ";", 
     RowBox[{"{", 
      RowBox[{"t", ",", "x", ",", "y", ",", "xd", ",", "yd"}], "}"}]}]}], 
   "\[IndentingNewLine]", "]"}]}]], "Input",
 CellChangeTimes->{{3.884599745435894*^9, 3.884599952174432*^9}, {
  3.884600220308159*^9, 3.8846002214146*^9}},
 CellLabel->"In[4]:=",ExpressionUUID->"24b4a3fc-1c40-4180-8325-aa48cae791c9"],

Cell[TextData[{
 "The function ",
 StyleBox["CRTBPPosVel", "Input"],
 " uses the ",
 StyleBox["CRTBP", "Input"],
 " function to solve the system of equations and produce a list of the time, \
position and velocity."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{
  3.8786458855917883`*^9, {3.884608901333068*^9, 3.884609030931868*^9}, {
   3.8846090783022537`*^9, 3.884609101958193*^9}, {3.884609161837578*^9, 
   3.88460945213229*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"9a6a5131-7620-4ff3-9655-567a4b693827"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBPPosVel", "[", 
   RowBox[{"mu_", ",", " ", 
    RowBox[{"{", 
     RowBox[{"x0_", ",", " ", "y0_", ",", " ", "xd0_", ",", " ", "yd0_"}], 
     "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"norb_", ",", "npo_"}], "}"}]}], "]"}], ":=", 
  "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"dt", "=", 
      RowBox[{"2", "*", 
       RowBox[{"Pi", "/", "npo"}]}]}], "}"}], ",", "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"output", "=", 
      RowBox[{"{", 
       RowBox[{"{", 
        RowBox[{"0", ",", "x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}], 
       "}"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"Do", "[", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"If", "[", 
         RowBox[{
          RowBox[{"i", "==", "1"}], ",", " ", 
          RowBox[{"start", "=", 
           RowBox[{"{", 
            RowBox[{"x0", ",", "y0", ",", "xd0", ",", "yd0"}], "}"}]}], ",", 
          " ", 
          RowBox[{"start", "=", "final"}]}], "]"}], ";", 
        RowBox[{"sol", " ", "=", " ", 
         RowBox[{"CRTBP", "[", 
          RowBox[{"mu", ",", " ", "start", ",", " ", 
           RowBox[{"{", 
            RowBox[{"0", ",", 
             RowBox[{"2", "*", "Pi"}]}], "}"}]}], "]"}]}], ";", 
        RowBox[{"pv", " ", "=", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{"Flatten", "[", 
            RowBox[{"N", "[", 
             RowBox[{
              RowBox[{"{", 
               RowBox[{
                RowBox[{"x", "[", "t", "]"}], ",", " ", 
                RowBox[{"y", "[", "t", "]"}], ",", " ", 
                RowBox[{"xd", "[", "t", "]"}], ",", " ", 
                RowBox[{"yd", "[", "t", "]"}]}], "}"}], " ", "/.", " ", 
              "sol"}], "]"}], "]"}], ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", " ", "0", ",", " ", 
             RowBox[{"2", "*", "Pi"}], ",", " ", "dt"}], "}"}]}], "]"}]}], 
        ";", 
        RowBox[{"tpv", "=", 
         RowBox[{"Transpose", "[", 
          RowBox[{"Join", "[", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"Table", "[", 
              RowBox[{
               RowBox[{"N", "[", "tp", "]"}], ",", 
               RowBox[{"{", 
                RowBox[{"tp", ",", 
                 RowBox[{"i", "-", "1"}], ",", "i", ",", 
                 RowBox[{"1", "/", "npo"}]}], "}"}]}], "]"}], "}"}], ",", 
            RowBox[{"Transpose", "[", "pv", "]"}]}], "]"}], "]"}]}], ";", 
        RowBox[{"output", "=", 
         RowBox[{"Join", "[", 
          RowBox[{"output", ",", " ", 
           RowBox[{"Drop", "[", 
            RowBox[{"tpv", ",", "1"}], "]"}]}], "]"}]}], ";", 
        RowBox[{"final", "=", 
         RowBox[{"Last", "[", "pv", "]"}]}]}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", "norb"}], "}"}]}], "\[IndentingNewLine]", 
      "]"}], ";", "\[IndentingNewLine]", "output"}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.88459998256313*^9, 3.884600101018793*^9}, {
   3.884605622093148*^9, 3.884605622449523*^9}, 3.885032927524745*^9},
 CellLabel->"In[5]:=",ExpressionUUID->"d505b651-76c2-41bc-867a-dd0e0fd7ac8a"],

Cell["Set the colours to be used for the  plot.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.885046960472136*^9, 3.8850469640563107`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ed9dfba6-c59a-40fa-957c-259cf15d9fb8"],

Cell[BoxData[
 RowBox[{
  RowBox[{"color1", "=", 
   RowBox[{"RGBColor", "[", 
    RowBox[{"0.368417`", ",", "0.506779`", ",", "0.709798`"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.884607205132513*^9, 3.884607206710265*^9}, {
  3.88504690402719*^9, 3.885046904535735*^9}},
 CellLabel->"In[6]:=",ExpressionUUID->"c3cf32e8-fb70-49a8-8624-e51ebd63da22"],

Cell["Set the initial reference orbit.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
  3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
  3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
  3.884609478322711*^9, 3.884609488822159*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"63acba9d-a227-41ed-85c4-1b3e8670ca45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindRoot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"Jacobi", "[", 
      RowBox[{"0.001", ",", 
       RowBox[{"{", 
        RowBox[{"0.56", ",", "0", ",", "0", ",", "ydot"}], "}"}]}], "]"}], 
     "-", "3.07"}], "==", "0"}], ",", 
   RowBox[{"{", 
    RowBox[{"ydot", ",", "1"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8849349940682993`*^9, 3.8849350903985777`*^9}, {
  3.8849369131977167`*^9, 3.884936913931712*^9}},
 CellLabel->"In[7]:=",ExpressionUUID->"ef1845e0-a642-4aaa-ac15-c9d0ccb66026"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"ydot", "\[Rule]", "0.8998072765093896`"}], "}"}]], "Output",
 CellChangeTimes->{3.884935092061715*^9, 3.884936716843547*^9, 
  3.884936921116844*^9, 3.884937335250963*^9, 3.885043834213828*^9, 
  3.885047055955421*^9, 3.891091037111348*^9},
 CellLabel->"Out[7]=",ExpressionUUID->"793da11c-f8be-4576-af71-e0681928ade3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"xy2ae", "[", 
  RowBox[{"0.001", ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", "0.56", ",", "0", ",", "0", ",", "0.899807"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.8849349227581387`*^9, 3.8849349641446457`*^9}, {
  3.884935101228853*^9, 3.884935105533313*^9}, {3.8849369332680397`*^9, 
  3.8849369610027514`*^9}},
 CellLabel->"In[8]:=",ExpressionUUID->"2733d572-27e5-4cb9-a808-d4d8926124dd"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.6952850998820844`", ",", "0.19457500226170207`", ",", "0.`", 
   ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.884935107199417*^9, 3.884936716865252*^9, {3.884936942267457*^9, 
   3.884936961560763*^9}, 3.88493733527542*^9, 3.885043834222805*^9, 
   3.885047055965047*^9, 3.891091037121724*^9},
 CellLabel->"Out[8]=",ExpressionUUID->"f10932a6-4ef4-4d1b-800e-242921946478"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"initial", "=", 
  RowBox[{"ae2xy", "[", 
   RowBox[{"0.001", ",", " ", 
    RowBox[{"{", 
     RowBox[{
     "0", ",", " ", "0.695285", ",", " ", "0.194575", ",", " ", "0", ",", " ",
       "0"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.8845985677654247`*^9, 3.8845985828783283`*^9}, {
  3.8846001171281757`*^9, 3.884600143287702*^9}, {3.8846923887675734`*^9, 
  3.884692418767*^9}, {3.884934887043941*^9, 3.8849349003028507`*^9}, {
  3.884935191994259*^9, 3.884935202223465*^9}, {3.884936967558968*^9, 
  3.884936980652399*^9}},
 CellLabel->"In[9]:=",ExpressionUUID->"f74bd00e-4dc2-4102-83dc-789011902668"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0.5599999211250001`", ",", "0.`", ",", "0.`", ",", 
   "0.899807180298681`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.884600241368472*^9, 3.884611336250744*^9, {3.8846924235308743`*^9, 
   3.8846924431196957`*^9}, 3.88492687447575*^9, 3.884934027671545*^9, 
   3.8849349027636433`*^9, 3.884935205510832*^9, 3.884936716873268*^9, 
   3.884936983182206*^9, 3.884937335284423*^9, 3.885043834274281*^9, 
   3.885047056009429*^9, 3.891091037150299*^9},
 CellLabel->"Out[9]=",ExpressionUUID->"d002e266-a659-4194-8aab-97fa571aedfa"]
}, Open  ]],

Cell["\<\
Carry out the numerical integration for 10000 Jupiter periods with 1000 \
points per orbit.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.884609528827335*^9}, {3.8846929395936604`*^9, 
   3.884692940103915*^9}, 3.884933818056218*^9, {3.88504319678268*^9, 
   3.885043197591806*^9}, {3.885045304172557*^9, 3.885045307293738*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ce0f8a9c-90e8-4147-a7e9-c7c8734b7d83"],

Cell[BoxData[
 RowBox[{
  RowBox[{"CRTBPPosVel", "[", 
   RowBox[{"0.001", ",", " ", 
    RowBox[{"Take", "[", 
     RowBox[{"initial", ",", 
      RowBox[{"-", "4"}]}], "]"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"10000", ",", "1000"}], "}"}]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.884602418272439*^9, 3.884602490946604*^9}, {
   3.884692833635356*^9, 3.88469283462359*^9}, 3.884692950109296*^9, {
   3.884694188205783*^9, 3.884694195342669*^9}, 3.8849352162641277`*^9, {
   3.884971921778871*^9, 3.8849719227951517`*^9}, {3.884971965234537*^9, 
   3.884971969235817*^9}, {3.885043017113604*^9, 3.885043017828022*^9}, {
   3.8850430956561337`*^9, 3.885043096445792*^9}, {3.885043200836392*^9, 
   3.8850432014346857`*^9}, {3.8850439293346243`*^9, 3.885043929943653*^9}, {
   3.8850439934443417`*^9, 3.8850439942200937`*^9}, {3.885044454513702*^9, 
   3.88504445509814*^9}, {3.885044519168523*^9, 3.885044519748213*^9}, {
   3.885044678930811*^9, 3.885044682215241*^9}, {3.885044859497208*^9, 
   3.885044860171001*^9}, {3.885045298608601*^9, 3.885045299461876*^9}},
 CellLabel->"In[10]:=",ExpressionUUID->"4b7e5027-a829-46ea-a699-58d2a31b2e98"],

Cell[TextData[{
 "Take the output data and store it in ",
 StyleBox["data", "Input"],
 "."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c66e205f-f841-4f3b-b401-3beca64997b5"],

Cell[BoxData[
 RowBox[{
  RowBox[{"data", "=", "output"}], ";"}]], "Input",
 CellChangeTimes->{{3.8846025272485447`*^9, 3.884602569500084*^9}, {
   3.884602604228772*^9, 3.884602608559495*^9}, 3.8849352265840397`*^9},
 CellLabel->"In[11]:=",ExpressionUUID->"b5dfc9c5-9977-4724-8bb9-72a67b93fe5a"],

Cell["Partition the data into overlapping pairs of values.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.8850164355553703`*^9, 
   3.885016466305386*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"a6a72254-afb1-480a-a609-d39b232faa6f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"pdata", "=", 
   RowBox[{"Partition", "[", 
    RowBox[{"data", ",", "2", ",", "1"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.884958972371325*^9, 3.884958996907157*^9}, {
  3.884971213593997*^9, 3.8849712452125683`*^9}, {3.885016425326809*^9, 
  3.885016426194372*^9}},
 CellLabel->"In[12]:=",ExpressionUUID->"cbf5b7f0-c6a8-41da-bee2-ce4758342f37"],

Cell[TextData[{
 "Select from the pairs those cases where the ",
 StyleBox["y",
  FontSlant->"Italic"],
 " value changes from negative to positive.  This means that ",
 StyleBox["ydot",
  FontSlant->"Italic"],
 " > 0 and we can use this to calculate the values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["xdot",
  FontSlant->"Italic"],
 " when y = 0.  The values of ",
 StyleBox["x",
  FontSlant->"Italic"],
 " and ",
 StyleBox["xdot",
  FontSlant->"Italic"],
 " will give us a point on the surface of section."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.885043218652596*^9, 
   3.885043244212302*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"00fcbe7e-c4ff-48d3-b2e3-1b83e804581d"],

Cell[BoxData[
 RowBox[{
  RowBox[{"spdata", "=", 
   RowBox[{"Select", "[", 
    RowBox[{"pdata", ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"1", ",", "3"}], "]"}], "]"}], "<=", "0"}], "&&", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", 
           RowBox[{"2", ",", "3"}], "]"}], "]"}], ">", "0"}]}], ")"}], 
      "&"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.8849712488918552`*^9, 3.884971345878228*^9}, {
  3.8849714433819113`*^9, 3.884971448598472*^9}, {3.885016480165959*^9, 
  3.885016487740059*^9}},
 CellLabel->"In[13]:=",ExpressionUUID->"28989704-952c-4a8b-80ec-9ba5c2c603e2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Short", "[", 
  RowBox[{"spdata", ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.885028194904706*^9, 3.885028196492848*^9}, {
  3.885031561061322*^9, 3.8850315679798813`*^9}},
 CellLabel->"In[14]:=",ExpressionUUID->"e9092624-329e-4987-8119-a06e81c8b31c"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "0", ",", "0.5599999211250001`", ",", "0.`", ",", "0.`", ",", 
        "0.899807180298681`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "0.001`", ",", "0.5599839224108857`", ",", "0.005653542044833125`", 
        ",", 
        RowBox[{"-", "0.005085445211097694`"}], ",", "0.8997561232228496`"}], 
       "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1.318`", ",", "0.7324068574466439`", ",", 
        RowBox[{"-", "0.002276116385116631`"}], ",", "0.2261712387398397`", 
        ",", "0.3834469926343901`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "1.319`", ",", "0.7338211642938466`", ",", "0.00012429895156694862`", 
        ",", "0.22402020409482942`", ",", "0.3806290433418063`"}], "}"}]}], 
     "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "8008", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9998.416`", ",", "0.8633385458960908`", ",", 
        RowBox[{"-", "0.00014040526049486973`"}], ",", 
        RowBox[{"-", "0.004772781316693682`"}], ",", "0.04180548882975201`"}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "9998.417`", ",", "0.8633019306732107`", ",", 
        "0.00012248344857779866`", ",", 
        RowBox[{"-", "0.006883516649926959`"}], ",", "0.04187877745170486`"}],
        "}"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"9999.698`", ",", "0.5970966079242024`", ",", 
        RowBox[{"-", "0.0017573801572687256`"}], ",", 
        RowBox[{"-", "0.34563447792563345`"}], ",", "0.7160332706490289`"}], 
       "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "9999.699`", ",", "0.5949098873711735`", ",", "0.0027553346075313324`",
         ",", 
        RowBox[{"-", "0.35043673157665434`"}], ",", "0.7203950963176288`"}], 
       "}"}]}], "}"}]}], "}"}],
  Short[#, 10]& ]], "Output",
 CellChangeTimes->{3.8850281977404537`*^9, 3.885031569133872*^9, 
  3.885038166772978*^9, 3.885038851690989*^9, 3.885043037925086*^9, 
  3.885043149826383*^9, 3.885043871896091*^9, 3.8850439751523457`*^9, 
  3.885044106473566*^9, 3.885044500918394*^9, 3.885044563538978*^9, 
  3.885044793990946*^9, 3.8850452204443617`*^9, 3.885046507306591*^9, 
  3.8850482139243*^9, 3.891092163937621*^9},
 CellLabel->
  "Out[14]//Short=",ExpressionUUID->"b087d778-e6a8-44dd-adde-da8b6171394b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"spdata", "[", 
  RowBox[{"[", "3", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.885044171972451*^9, 3.885044204056509*^9}},
 CellLabel->"In[15]:=",ExpressionUUID->"9fbb0a66-55c9-40df-9f08-912466095b50"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2.819`", ",", "0.6042948566922255`", ",", 
     RowBox[{"-", "0.00127661156289542`"}], ",", 
     RowBox[{"-", "0.2488874054380115`"}], ",", "0.7342742502038685`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2.82`", ",", "0.6027182096416042`", ",", "0.003346806027531942`", ",", 
     RowBox[{"-", "0.2529848450047877`"}], ",", "0.7374044369183118`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.885044175249979*^9, 3.8850442046662397`*^9}, 
   3.885044500927927*^9, 3.885044563548464*^9, 3.885044794001809*^9, 
   3.88504522045573*^9, 3.8850465073204327`*^9, 3.885048213937811*^9, 
   3.891092163948748*^9},
 CellLabel->"Out[15]=",ExpressionUUID->"eee468e5-92e1-4fd4-82b2-a84925cb52bd"]
}, Open  ]],

Cell[TextData[{
 "Take the first value of each pair.  We are using a fixed interval of 0.001 \
orbital periods and so we just have to find the time at which ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0 occurs."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.8850415775728407`*^9, 
   3.885041646037519*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"ca3f36a6-d42a-410c-a1a5-6f9b12963c3a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fspdata", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "spdata", "]"}], "[", 
    RowBox[{"[", "1", "]"}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.885041537631114*^9, 3.8850415645349493`*^9}},
 CellLabel->"In[16]:=",ExpressionUUID->"9eb3a93e-3375-4a3f-8d1a-c45742e23de0"],

Cell[TextData[{
 "Define a function ",
 StyleBox["Zoom", "Input"],
 " to zoom in on the crossing point.  It does this by repeating the \
integration over the same interval and then fitting the values of ",
 StyleBox["y",
  FontSlant->"Italic"],
 " to calculate the value of the time when ",
 StyleBox["y",
  FontSlant->"Italic"],
 " = 0."
}], "Text",
 CellFrame->True,
 CellChangeTimes->{{3.878562591887006*^9, 3.878562613471806*^9}, {
   3.878645977794298*^9, 3.878646003488901*^9}, {3.878646081324325*^9, 
   3.878646113633102*^9}, {3.884607227808136*^9, 3.884607228482621*^9}, {
   3.884609478322711*^9, 3.8846095608669577`*^9}, {3.8846096199976463`*^9, 
   3.884609628178115*^9}, 3.8850147686733027`*^9, {3.885016496814961*^9, 
   3.885016531885009*^9}, {3.8850285015797462`*^9, 3.88502856691998*^9}, {
   3.885041218359777*^9, 3.8850412205947866`*^9}, {3.885041306797385*^9, 
   3.8850413423777447`*^9}, {3.885042066171073*^9, 3.885042086106042*^9}, {
   3.885042945004177*^9, 3.8850429751686783`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"b3609775-43ed-4809-b12e-6d9ff1e37b18"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Zoom", "[", "ival_", "]"}], ":=", "\[IndentingNewLine]", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"zstart", ",", 
      RowBox[{"rt2", "=", 
       RowBox[{"N", "[", 
        RowBox[{"2", "*", 
         RowBox[{"\[Pi]", "/", "1000"}]}], "]"}]}], ",", "zsol", ",", "res", 
      ",", "tval", ",", "xvals", ",", "yvals", ",", "xdvals", ",", "ydval", 
      ",", "yfit", ",", "tfit", ",", "stfit", ",", "answer"}], "}"}], ",", 
    "\[IndentingNewLine]", 
    RowBox[{
     RowBox[{"zstart", "=", 
      RowBox[{"Take", "[", 
       RowBox[{"ival", ",", 
        RowBox[{"-", "4"}]}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"zsol", "=", 
      RowBox[{"CRTBP", "[", 
       RowBox[{"0.001", ",", " ", "zstart", ",", " ", 
        RowBox[{"{", 
         RowBox[{"0", ",", " ", 
          RowBox[{"2", "*", 
           RowBox[{"\[Pi]", "/", "1000"}]}]}], "}"}]}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"res", "=", "\[IndentingNewLine]", 
      RowBox[{"Partition", "[", 
       RowBox[{
        RowBox[{"Flatten", "[", 
         RowBox[{"Table", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"{", 
             RowBox[{
              RowBox[{"N", "[", 
               RowBox[{
                RowBox[{"t", "/", "2"}], "/", "\[Pi]"}], "]"}], ",", 
              RowBox[{"x", "[", "t", "]"}], ",", " ", 
              RowBox[{"y", "[", "t", "]"}], ",", " ", 
              RowBox[{"xd", "[", "t", "]"}], ",", " ", 
              RowBox[{"yd", "[", "t", "]"}]}], "}"}], "/.", " ", "zsol"}], 
           ",", 
           RowBox[{"{", 
            RowBox[{"t", ",", "0", ",", "rt2", ",", 
             RowBox[{"2", 
              RowBox[{"\[Pi]", "/", "10000"}]}]}], "}"}]}], "]"}], "]"}], ",",
         "5"}], "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "tval", ",", "xvals", ",", "yvals", ",", "xdvals", ",", "ydval"}], 
       "}"}], "=", 
      RowBox[{"Transpose", "[", "res", "]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"yfit", "=", 
      RowBox[{"Fit", "[", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"tval", ",", "yvals"}], "}"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "x"}], "}"}], ",", "x"}], "]"}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"tfit", "=", 
      RowBox[{"x", "/.", 
       RowBox[{"FindRoot", "[", 
        RowBox[{
         RowBox[{"yfit", "==", "0"}], ",", 
         RowBox[{"{", 
          RowBox[{"x", ",", "0"}], "}"}]}], "]"}]}]}], ";", 
     "\[IndentingNewLine]", 
     RowBox[{"stfit", "=", 
      RowBox[{"tfit", "*", "2", "\[Pi]"}]}], ";", "\[IndentingNewLine]", 
     RowBox[{"answer", "=", 
      RowBox[{"Flatten", "[", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          RowBox[{"N", "[", "stfit", "]"}], ",", 
          RowBox[{"x", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"y", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"xd", "[", "stfit", "]"}], ",", " ", 
          RowBox[{"yd", "[", "stfit", "]"}]}], "}"}], "/.", "zsol"}], "]"}]}],
      ";", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"answer", "[", 
        RowBox[{"[", "2", "]"}], "]"}], ",", 
       RowBox[{"answer", "[", 
        RowBox[{"[", "4", "]"}], "]"}]}], "}"}]}]}], "\[IndentingNewLine]", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.885041356732667*^9, 3.885041357541669*^9}, 
   3.885041662688059*^9, {3.8850417350469513`*^9, 3.885041741872347*^9}, {
   3.885041814262137*^9, 3.88504181739717*^9}, {3.885041989319838*^9, 
   3.8850420430417833`*^9}, {3.885042115651099*^9, 3.885042124431017*^9}, {
   3.885042166890789*^9, 3.885042241491126*^9}, {3.885042271785565*^9, 
   3.885042436071013*^9}},
 CellLabel->"In[17]:=",ExpressionUUID->"7ebe3619-8c24-4dc1-825c-7c30deed09a2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "fspdata", "]"}]], "Input",
 CellChangeTimes->{{3.885042472041195*^9, 3.885042475579356*^9}, {
  3.885042994248928*^9, 3.8850430008481617`*^9}},
 CellLabel->"In[18]:=",ExpressionUUID->"43d451e9-5b18-4fee-8dee-e18f061b526d"],

Cell[BoxData["8012"], "Output",
 CellChangeTimes->{3.885042476925583*^9, 3.885043001820582*^9, 
  3.885043037997079*^9, 3.8850431498925343`*^9, 3.885043886475442*^9, 
  3.885043975219371*^9, 3.885044106542981*^9, 3.885044500999807*^9, 
  3.88504456366296*^9, 3.885044794106319*^9, 3.885045220526311*^9, 
  3.885046507564394*^9, 3.885048214038865*^9, 3.891092164040535*^9},
 CellLabel->"Out[18]=",ExpressionUUID->"82382d1e-fd33-4c16-b931-f6d45cec44db"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"sspoints", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Zoom", "[", "#", "]"}], "&"}], ",", "fspdata"}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.885042444565172*^9, 3.885042487204574*^9}, {
  3.885042708184396*^9, 3.8850427576244793`*^9}},
 CellLabel->"In[19]:=",ExpressionUUID->"ba1b5dab-a065-476b-9303-5f2744d9ff6a"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction", "dmval", 
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"4.979185195808551`*^-7\\\"}], \\\"}\\\"}]\\) lies outside the range of \
data in the interpolating function. Extrapolation will be used.\"", 2, 19, 1, 
   25812262188959988809, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.885044818669731*^9, 3.885045227348544*^9, 
  3.88504651416326*^9, 3.885048220425233*^9, 3.8910921704535913`*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"0a513be0-d4e9-48cb-9e5b-a71d1b74dd97"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction", "dmval", 
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"4.979185195808551`*^-7\\\"}], \\\"}\\\"}]\\) lies outside the range of \
data in the interpolating function. Extrapolation will be used.\"", 2, 19, 2, 
   25812262188959988809, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.885044818669731*^9, 3.885045227348544*^9, 
  3.88504651416326*^9, 3.885048220425233*^9, 3.891092170488192*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"e11e127e-94ba-4ae3-b77e-18f49d6ad120"],

Cell[BoxData[
 TemplateBox[{
  "InterpolatingFunction", "dmval", 
   "\"Input value \\!\\(\\*RowBox[{\\\"{\\\", RowBox[{\\\"-\\\", \
\\\"4.979185195808551`*^-7\\\"}], \\\"}\\\"}]\\) lies outside the range of \
data in the interpolating function. Extrapolation will be used.\"", 2, 19, 3, 
   25812262188959988809, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.885044818669731*^9, 3.885045227348544*^9, 
  3.88504651416326*^9, 3.885048220425233*^9, 3.891092170496399*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"dda2ee25-bee8-470c-ab72-193ea3493f8a"],

Cell[BoxData[
 TemplateBox[{
  "General", "stop", 
   "\"Further output of \\!\\(\\*StyleBox[RowBox[{\\\"InterpolatingFunction\\\
\", \\\"::\\\", \\\"dmval\\\"}], \\\"MessageName\\\"]\\) will be suppressed \
during this calculation.\"", 2, 19, 4, 25812262188959988809, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.885044818669731*^9, 3.885045227348544*^9, 
  3.88504651416326*^9, 3.885048220425233*^9, 3.891092170503759*^9},
 CellLabel->
  "During evaluation of \
In[19]:=",ExpressionUUID->"0bf2900a-aee8-49d5-aa08-12bc5748d1d9"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Length", "[", "sspoints", "]"}]], "Input",
 CellChangeTimes->{{3.885044836457053*^9, 3.885044842576263*^9}},
 CellLabel->"In[20]:=",ExpressionUUID->"d146eac8-c9fb-46ec-bc6e-57af156726c0"],

Cell[BoxData["8012"], "Output",
 CellChangeTimes->{3.885044843880106*^9, 3.885045237806697*^9, 
  3.885046540857731*^9, 3.8850482464179897`*^9, 3.891092196524983*^9},
 CellLabel->"Out[20]=",ExpressionUUID->"610a6ba2-17e1-421d-a715-db87da3a268f"]
}, Open  ]],

Cell["Define the axis labels.", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"c3cda3e9-d160-4c42-87f3-5964d4020dd5"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"xlabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
StyleBox[\"x\", \"TI\"], TraditionalForm], \"errors\" -> {}, \"input\" -> \"x\
\", \"state\" -> \"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"ylabel", "=", "\"\<\!\(\*TemplateBox[<|\"boxes\" -> FormBox[
OverscriptBox[
StyleBox[\"x\", \"TI\"], \".\"], TraditionalForm], \"errors\" -> {}, \
\"input\" -> \"\\\\dot x\", \"state\" -> \
\"Boxes\"|>,\"TeXAssistantTemplate\"]\)\>\""}], ";"}]}], "Input",
 CellChangeTimes->{{3.851338850796014*^9, 3.851338856475478*^9}, {
  3.851339056483313*^9, 3.851339071079105*^9}, {3.8790751708185472`*^9, 
  3.879075193961151*^9}, {3.8790752823156977`*^9, 3.879075295960511*^9}, {
  3.8846966972447853`*^9, 3.884696730405851*^9}, {3.88493529231481*^9, 
  3.8849353055043716`*^9}, {3.8850433516886263`*^9, 3.885043376888672*^9}},
 CellLabel->"In[21]:=",ExpressionUUID->"2176cbc8-751f-447a-8aaf-0d34ef27e3ba"],

Cell["\<\
Now plot the points in the surface of section for this chaotic trajectory.  \
This is Fig.9.7.\
\>", "Text",
 CellFrame->True,
 CellChangeTimes->{{3.869373084037505*^9, 3.869373204667523*^9}, {
  3.869552502127846*^9, 3.869552527987165*^9}, {3.8695525676926813`*^9, 
  3.869552627902935*^9}, {3.869552688038094*^9, 3.8695527321988773`*^9}, {
  3.86955276584477*^9, 3.8695527789835157`*^9}, {3.869552853609722*^9, 
  3.8695529191526623`*^9}, {3.869553047085703*^9, 3.869553087120385*^9}, {
  3.870607952402626*^9, 3.870607986048612*^9}, {3.870608112694354*^9, 
  3.870608186135066*^9}, {3.870608226185451*^9, 3.8706082321707907`*^9}, {
  3.885043607290801*^9, 3.885043635581582*^9}, {3.8850439007087*^9, 
  3.8850439026129627`*^9}, {3.885047029906289*^9, 3.885047030385612*^9}},
 Background->GrayLevel[
  0.849989],ExpressionUUID->"2d732a05-09e5-4939-a202-e11b0caa4aca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"sspoints", ",", 
   RowBox[{"PlotStyle", "->", "color1"}], ",", 
   RowBox[{"PlotRange", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"0.45", ",", "0.9"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "0.4"}], ",", "0.4"}], "}"}]}], "}"}]}], ",", 
   RowBox[{"Frame", "->", "True"}], ",", " ", 
   RowBox[{"FrameLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"xlabel", ",", 
      RowBox[{"Rotate", "[", 
       RowBox[{"ylabel", ",", 
        RowBox[{
         RowBox[{"-", "\[Pi]"}], "/", "2"}]}], "]"}]}], "}"}]}], ",", 
   RowBox[{"FrameStyle", "->", 
    RowBox[{"Thickness", "[", "0.004", "]"}]}], ",", "\[IndentingNewLine]", 
   RowBox[{"LabelStyle", "\[Rule]", 
    RowBox[{"Directive", "[", 
     RowBox[{
      RowBox[{"FontFamily", "\[Rule]", "\"\<Times\>\""}], ",", 
      RowBox[{"FontSize", "\[Rule]", "16"}]}], "]"}]}], ",", 
   RowBox[{"AxesOrigin", "->", 
    RowBox[{"{", 
     RowBox[{"0.45", ",", 
      RowBox[{"-", "0.4"}]}], "}"}]}], ",", 
   RowBox[{"PlotRangePadding", "->", "None"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.885043417300242*^9, 3.885043497444316*^9}, 
   3.8850435453266973`*^9},
 CellLabel->"In[23]:=",ExpressionUUID->"60d4bcd2-7086-494a-8289-95440b1b21f0"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
     NCache[
      Rational[1, 360], 0.002777777777777778]], AbsoluteThickness[1.6], 
    PointBox[CompressedData["
1:eJwUmHcgle8bxklKIRHpayZ7RKmkwU3ZW1ZlJZRUykhFUqiUkoxkJCtlUzZ5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     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0.45, -0.4},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox[
       RotationBox[
       "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> \
FormBox[OverscriptBox[StyleBox[\\\"x\\\", \\\"TI\\\"], \\\".\\\"], \
TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"\\\\\\\\dot \
x\\\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
        BoxRotation -> -1.5707963267948966`], HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox[
      "\"\\!\\(\\*TemplateBox[<|\\\"boxes\\\" -> FormBox[StyleBox[\\\"x\\\", \
\\\"TI\\\"], TraditionalForm], \\\"errors\\\" -> {}, \\\"input\\\" -> \\\"x\\\
\", \\\"state\\\" -> \\\"Boxes\\\"|>,\\\"TeXAssistantTemplate\\\"]\\)\"", 
       HoldForm], TraditionalForm], None}},
  FrameStyle->Thickness[0.004],
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  LabelStyle->Directive[FontFamily -> "Times", FontSize -> 16],
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0.45, 0.9}, {-0.4, 0.4}},
  PlotRangeClipping->True,
  PlotRangePadding->{{None, None}, {None, None}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.885043164639765*^9, {3.885043482638938*^9, 3.8850434989739428`*^9}, 
   3.8850439073810596`*^9, 3.885043979174197*^9, 3.885044114630046*^9, 
   3.885044827663485*^9, 3.8850452380027514`*^9, 3.885046541202629*^9, 
   3.88504824681135*^9, 3.89109219693738*^9},
 CellLabel->"Out[23]=",ExpressionUUID->"0dfef45c-78a7-4359-be6b-3d787cedfcbf"]
}, Open  ]]
},
CellGrouping->Manual,
WindowSize->{1059, 665},
WindowMargins->{{17, Automatic}, {Automatic, 23}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"13.2 for Mac OS X x86 (64-bit) (November 18, 2022)",
StyleDefinitions->"Default.nb",
ExpressionUUID->"d38488ee-5b65-457a-a415-e5dca8af6771"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 489, 10, 53, "Text",ExpressionUUID->"e00740cc-6281-478c-8bb6-75443996002a"],
Cell[1050, 32, 430, 6, 67, "Section",ExpressionUUID->"98580719-04ac-49a4-b957-796e13d2fd0c"],
Cell[1483, 40, 425, 10, 72, "Text",ExpressionUUID->"2196beda-83cc-4949-84e5-6855091b3920"],
Cell[1911, 52, 4408, 115, 304, "Input",ExpressionUUID->"a0cc8023-92c0-48cc-8003-9af569b81a86"],
Cell[6322, 169, 356, 9, 53, "Text",ExpressionUUID->"e62b02b3-a858-4e86-bbbf-40af19ca2286"],
Cell[6681, 180, 1540, 45, 115, "Input",ExpressionUUID->"cc76bdeb-e5fc-4e00-a682-cd7f21c16a0c"],
Cell[8224, 227, 523, 12, 76, "Text",ExpressionUUID->"b21a35eb-c629-442c-bfb9-7016cce5ed6b"],
Cell[8750, 241, 5856, 160, 724, "Input",ExpressionUUID->"7a749214-1746-4618-a6ff-697ddfaa8116"],
Cell[14609, 403, 526, 12, 76, "Text",ExpressionUUID->"454a8d3b-0bf3-479e-8a9f-22b4ef58bce3"],
Cell[15138, 417, 4818, 128, 640, "Input",ExpressionUUID->"24b4a3fc-1c40-4180-8325-aa48cae791c9"],
Cell[19959, 547, 531, 14, 53, "Text",ExpressionUUID->"9a6a5131-7620-4ff3-9655-567a4b693827"],
Cell[20493, 563, 3222, 82, 283, "Input",ExpressionUUID->"d505b651-76c2-41bc-867a-dd0e0fd7ac8a"],
Cell[23718, 647, 428, 7, 53, "Text",ExpressionUUID->"ed9dfba6-c59a-40fa-957c-259cf15d9fb8"],
Cell[24149, 656, 362, 8, 33, "Input",ExpressionUUID->"c3cf32e8-fb70-49a8-8624-e51ebd63da22"],
Cell[24514, 666, 417, 7, 53, "Text",ExpressionUUID->"63acba9d-a227-41ed-85c4-1b3e8670ca45"],
Cell[CellGroupData[{
Cell[24956, 677, 544, 14, 30, "Input",ExpressionUUID->"ef1845e0-a642-4aaa-ac15-c9d0ccb66026"],
Cell[25503, 693, 358, 6, 34, "Output",ExpressionUUID->"793da11c-f8be-4576-af71-e0681928ade3"]
}, Open  ]],
Cell[CellGroupData[{
Cell[25898, 704, 427, 9, 30, "Input",ExpressionUUID->"2733d572-27e5-4cb9-a808-d4d8926124dd"],
Cell[26328, 715, 437, 9, 34, "Output",ExpressionUUID->"f10932a6-4ef4-4d1b-800e-242921946478"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26802, 729, 641, 13, 30, "Input",ExpressionUUID->"f74bd00e-4dc2-4102-83dc-789011902668"],
Cell[27446, 744, 581, 11, 34, "Output",ExpressionUUID->"d002e266-a659-4194-8aab-97fa571aedfa"]
}, Open  ]],
Cell[28042, 758, 656, 12, 53, "Text",ExpressionUUID->"ce0f8a9c-90e8-4147-a7e9-c7c8734b7d83"],
Cell[28701, 772, 1160, 20, 30, "Input",ExpressionUUID->"4b7e5027-a829-46ea-a699-58d2a31b2e98"],
Cell[29864, 794, 552, 12, 53, "Text",ExpressionUUID->"c66e205f-f841-4f3b-b401-3beca64997b5"],
Cell[30419, 808, 296, 5, 30, "Input",ExpressionUUID->"b5dfc9c5-9977-4724-8bb9-72a67b93fe5a"],
Cell[30718, 815, 570, 9, 53, "Text",ExpressionUUID->"a6a72254-afb1-480a-a609-d39b232faa6f"],
Cell[31291, 826, 391, 8, 30, "Input",ExpressionUUID->"cbf5b7f0-c6a8-41da-bee2-ce4758342f37"],
Cell[31685, 836, 1194, 31, 76, "Text",ExpressionUUID->"00fcbe7e-c4ff-48d3-b2e3-1b83e804581d"],
Cell[32882, 869, 721, 20, 30, "Input",ExpressionUUID->"28989704-952c-4a8b-80ec-9ba5c2c603e2"],
Cell[CellGroupData[{
Cell[33628, 893, 283, 5, 30, "Input",ExpressionUUID->"e9092624-329e-4987-8119-a06e81c8b31c"],
Cell[33914, 900, 2509, 62, 112, "Output",ExpressionUUID->"b087d778-e6a8-44dd-adde-da8b6171394b"]
}, Open  ]],
Cell[CellGroupData[{
Cell[36460, 967, 227, 4, 30, "Input",ExpressionUUID->"9fbb0a66-55c9-40df-9f08-912466095b50"],
Cell[36690, 973, 779, 17, 34, "Output",ExpressionUUID->"eee468e5-92e1-4fd4-82b2-a84925cb52bd"]
}, Open  ]],
Cell[37484, 993, 877, 17, 53, "Text",ExpressionUUID->"ca3f36a6-d42a-410c-a1a5-6f9b12963c3a"],
Cell[38364, 1012, 317, 7, 30, "Input",ExpressionUUID->"9eb3a93e-3375-4a3f-8d1a-c45742e23de0"],
Cell[38684, 1021, 1099, 23, 76, "Text",ExpressionUUID->"b3609775-43ed-4809-b12e-6d9ff1e37b18"],
Cell[39786, 1046, 3898, 98, 283, "Input",ExpressionUUID->"7ebe3619-8c24-4dc1-825c-7c30deed09a2"],
Cell[CellGroupData[{
Cell[43709, 1148, 261, 4, 30, "Input",ExpressionUUID->"43d451e9-5b18-4fee-8dee-e18f061b526d"],
Cell[43973, 1154, 451, 6, 34, "Output",ExpressionUUID->"82382d1e-fd33-4c16-b931-f6d45cec44db"]
}, Open  ]],
Cell[CellGroupData[{
Cell[44461, 1165, 391, 10, 30, "Input",ExpressionUUID->"ba1b5dab-a065-476b-9303-5f2744d9ff6a"],
Cell[44855, 1177, 603, 12, 31, "Message",ExpressionUUID->"0a513be0-d4e9-48cb-9e5b-a71d1b74dd97"],
Cell[45461, 1191, 601, 12, 31, "Message",ExpressionUUID->"e11e127e-94ba-4ae3-b77e-18f49d6ad120"],
Cell[46065, 1205, 601, 12, 31, "Message",ExpressionUUID->"dda2ee25-bee8-470c-ab72-193ea3493f8a"],
Cell[46669, 1219, 556, 11, 28, "Message",ExpressionUUID->"0bf2900a-aee8-49d5-aa08-12bc5748d1d9"]
}, Open  ]],
Cell[CellGroupData[{
Cell[47262, 1235, 211, 3, 30, "Input",ExpressionUUID->"d146eac8-c9fb-46ec-bc6e-57af156726c0"],
Cell[47476, 1240, 245, 3, 34, "Output",ExpressionUUID->"610a6ba2-17e1-421d-a715-db87da3a268f"]
}, Open  ]],
Cell[47736, 1246, 656, 10, 53, "Text",ExpressionUUID->"c3cda3e9-d160-4c42-87f3-5964d4020dd5"],
Cell[48395, 1258, 993, 17, 54, "Input",ExpressionUUID->"2176cbc8-751f-447a-8aaf-0d34ef27e3ba"],
Cell[49391, 1277, 879, 15, 53, "Text",ExpressionUUID->"2d732a05-09e5-4939-a202-e11b0caa4aca"],
Cell[CellGroupData[{
Cell[50295, 1296, 1311, 34, 73, "Input",ExpressionUUID->"60d4bcd2-7086-494a-8289-95440b1b21f0"],
Cell[51609, 1332, 169785, 2822, 271, "Output",ExpressionUUID->"0dfef45c-78a7-4359-be6b-3d787cedfcbf"]
}, Open  ]]
}
]
*)

